-- Table definition for REORGCHK stats at index level.
-- Change the tablespace if necessary, and select a single partition tablespace.
-- On a DPF system, this will typically be a single partition tablespace outside the catalog partition.
-- On a single partition database, USERSPACE1 may well be adequate; a 4K pagesize is fine for this workload.

-- Alex Levy, Sustainable Software Ltd. http://www.sustainablesoftware.net
-- July 2005, revised for publication on the web March 2006.
-- Updated for DB2 V9.1, Oct 2006 and Oct 2008.
-- Updated for DB2 V9.5, March 2011.
-- Updated for DB2 V9.7, May 2012.

-- Alex, May 2012

set current schema current user ;
   
-- The definition of the table data returned by a call to sysproc.reorgchk_ix_stats can change between DB2 versions;
-- the next 2 statements future-proof and keep in step without having to alter the create table statement at each release!
-- Fortunately the proc creates a declared global temporary table so this script is called with autocommit off.

call sysproc.reorgchk_ix_stats('T','SYSIBM.SYSTABLES') ;
create table reorgchk_ix 
       like session.ix_stats
       in userspace1
       partitioning key (table_schema, table_name)
;
comment on table reorgchk_ix is 'Holds results of call(s) to sysproc.reorgchk_ix_stats.'
;
create unique index reorgchk_ix_u1 on reorgchk_ix
(table_schema asc, table_name asc, index_schema asc, index_name asc)
allow reverse scans
cluster minpctused 49
;
   
comment on index reorgchk_ix_u1 is 'A table can have multiple indexes; We assume the index and table schemata are always identical.'
;

-- V9.1 (now sunsetted) renamed CARD to INDCARD, removed ISIZE; and added 4 new columns (LEAF_RECSIZE,NONLEAF_RECSIZE,LEAF_PAGE_OVERHEAD
-- and NONLEAF_AGE_OVERHEAD). The changes are commented out below, you may want to comment them back in depending on
-- current DB2 version.
-- V9.7 added columns DATAPARTITIONNAME and PCT_PAGES_SAVED

comment on reorgchk_ix 
(
TABLE_SCHEMA   IS 'Table schema for the REORGCHK''''d table.' 
,TABLE_NAME    IS 'Table name for the REORGCHK''''D table.' 
,INDEX_SCHEMA  IS 'Index schema for the REORGCHK''''d table.'
,INDEX_NAME    IS 'Index name (one of many) for the REORGCHK''''d table.'
,DATAPARTITIONNAME IS 'Name of the data (range) partition. NULL for nonpartitioned tables.'
,INDCARD       IS 'Number of index entries in the index, from the last RUNSTATS; set as -1 if no RUNSTATS was run.'
,NLEAF         IS 'Total number of index leaf pages from the last runstats;  set as -1 if no RUNSTATS was run.'
,NUM_EMPTY_LEAFS IS 'Number of pseudo-empty index leaf pages; set as -1 if no RUNSTATS was run.' 
,NLEVELS       IS 'Number of index levels; -1 if no RUNSTATS has been run.'  
,NUMRIDS_DELETED IS 'Number of pseudo-deleted RIDs; set as -1 if no RUNSTATS was run.'
,FULLKEYCARD   IS 'Number of unique index entries not marked as deleted; set as -1 if no RUNSTATS was run.' 
,LEAF_RECSIZE  IS 'Average size of an index entry, excluding overhead, on a leaf page.'
,NONLEAF_RECSIZE  IS 'Average size of an index entry, excluding overhead and INCLUDE columns, on a non-leaf page.'
,LEAF_PAGE_OVERHEAD  IS 'Reserved space on a leaf page for DB2 internal use.'
,NONLEAF_PAGE_OVERHEAD  IS 'Reserved space on a non-leaf page for DB2 internal use.'
,PCT_PAGES_SAVED IS 'Percent of pages saved using Index Compression. A non-zero number indicates the index is compressed.'
,F4            IS 'Reorgchk F4 formula value.'  
,F5            IS 'Reorgchk F5 formula value.'  
,F6            IS 'Reorgchk F6 formula value.'
,F7            IS 'Reorgchk F7 formula value.'  
,F8            IS 'Reorgchk F8 formula value.'  
,REORG         IS 'A 5 character field mapping to the 5 formulae: F4 through F8. A dash means that the formula value is in the recommended range; an asterisk means the formula value is out of the recommended range, indicating a need for reorganization.'
)
;
