-- Table definition for REORGCHK stats at table level.
-- Change the tablespace name if necessary, selecting a single partition tablespace.
-- On a DPF system, this will typically be a single partition tablespace outside the catalog partition.
-- On a single partition database, USERSPACE1 may well be adequate; a 4K pagesize is fine for this workload.

-- Alex Levy, Sustainable Software Ltd. http://www.sustainablesoftware.net
-- July 2005, revised for publication on the web March 2006.
-- Updated for DB2 V9.1, Oct 2006 and Oct 2008.
-- Updated for DB2 V9.5, March 2011.
-- Updated for DB2 V9.7, May 2012.

-- Alex, May 2012

set current schema current user ;

-- The definition of the table data returned by a call to sysproc.reorgchk_tb_stats changed between DB2 and within versions 8 and 9;
-- the next 2 statements future-proof and keep in step without having to alter the CREATE TABLE statement at each release.
-- Fortunately the proc creates a declared global temporary table which acts as a template, so this script is called with autocommit off.

call sysproc.reorgchk_tb_stats('T','SYSIBM.SYSTABLES') ;
create table reorgchk_tb 
       like session.tb_stats
       in userspace1
       partitioning key (table_schema, table_name)
;
comment on table reorgchk_tb is 'Holds results of call(s) to sysproc.reorgchk_tb_stats.'
;
create unique index reorgchk_tb_u1 on reorgchk_tb
(table_schema asc, table_name asc)
allow reverse scans
cluster minpctused 49
;
--alter table reorgchk_tb 
--      add constraint reorgchk_tb_p1 primary key
--      (table_schema , table_name )
--;

comment on index reorgchk_tb_u1 is 'Enforce uniqueneness on the qualified table name and improve subsequent join performance.'
;
comment on reorgchk_tb 
(
TABLE_SCHEMA   IS 'Table schema for the REORGCHK''''d table.' 
,TABLE_NAME    IS 'Table name for the REORGCHK''''D table.' 
,DATAPARTITIONNAME IS 'Name of the data (range) partition. NULL for non range-partitioned tables.'
,CARD          IS 'Cardinality, or number of rows in the table, from the last RUNSTATS; set as -1 if no RUNSTATS was run.'
,OVERFLOW      IS 'Number of overflow rows from the last runstats;  set as -1 if no RUNSTATS was run.'
,NPAGES        IS 'Required pages; -1 if no RUNSTATS has been run.'  
,FPAGES        IS 'Free pages; -1 if no RUNSTATS has been run.'  
,ACTIVE_BLOCKS IS 'Number of active blocks for an MDC table; -1 if it is not a MDC table.'
,TSIZE         is 'Table size byte count - not known how RUNSTATS calculates this.'  
,F1            IS 'Reorgchk F1 formula value.'  
,F2            IS 'Reorgchk F2 formula value.'  
,F3            IS 'Reorgchk F3 formula value.'  
,REORG         IS 'A 3 character field mapping to the three formulae: F1, F2, and F3. A dash means that the formula value is in the recommended range; an asterisk means the formula value is out of the recommended range, indicating a need for reorganization.'
)
;
